/****************************************************************************
** Meta object code from reading C++ file 'phonenumber.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kcontacts-5.116.0/src/phonenumber.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'phonenumber.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KContacts__PhoneNumber_t {
    QByteArrayData data[26];
    char stringdata0[190];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts__PhoneNumber_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts__PhoneNumber_t qt_meta_stringdata_KContacts__PhoneNumber = {
    {
QT_MOC_LITERAL(0, 0, 22), // "KContacts::PhoneNumber"
QT_MOC_LITERAL(1, 23, 2), // "id"
QT_MOC_LITERAL(2, 26, 6), // "number"
QT_MOC_LITERAL(3, 33, 16), // "normalizedNumber"
QT_MOC_LITERAL(4, 50, 4), // "type"
QT_MOC_LITERAL(5, 55, 4), // "Type"
QT_MOC_LITERAL(6, 60, 9), // "typeLabel"
QT_MOC_LITERAL(7, 70, 7), // "isEmpty"
QT_MOC_LITERAL(8, 78, 11), // "isPreferred"
QT_MOC_LITERAL(9, 90, 11), // "supportsSms"
QT_MOC_LITERAL(10, 102, 8), // "TypeFlag"
QT_MOC_LITERAL(11, 111, 4), // "Home"
QT_MOC_LITERAL(12, 116, 4), // "Work"
QT_MOC_LITERAL(13, 121, 3), // "Msg"
QT_MOC_LITERAL(14, 125, 4), // "Pref"
QT_MOC_LITERAL(15, 130, 5), // "Voice"
QT_MOC_LITERAL(16, 136, 3), // "Fax"
QT_MOC_LITERAL(17, 140, 4), // "Cell"
QT_MOC_LITERAL(18, 145, 5), // "Video"
QT_MOC_LITERAL(19, 151, 3), // "Bbs"
QT_MOC_LITERAL(20, 155, 5), // "Modem"
QT_MOC_LITERAL(21, 161, 3), // "Car"
QT_MOC_LITERAL(22, 165, 4), // "Isdn"
QT_MOC_LITERAL(23, 170, 3), // "Pcs"
QT_MOC_LITERAL(24, 174, 5), // "Pager"
QT_MOC_LITERAL(25, 180, 9) // "Undefined"

    },
    "KContacts::PhoneNumber\0id\0number\0"
    "normalizedNumber\0type\0Type\0typeLabel\0"
    "isEmpty\0isPreferred\0supportsSms\0"
    "TypeFlag\0Home\0Work\0Msg\0Pref\0Voice\0Fax\0"
    "Cell\0Video\0Bbs\0Modem\0Car\0Isdn\0Pcs\0"
    "Pager\0Undefined"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts__PhoneNumber[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       8,   14, // properties
       1,   38, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095103,
       2, QMetaType::QString, 0x00095103,
       3, QMetaType::QString, 0x00095001,
       4, 0x80000000 | 5, 0x0009510b,
       6, QMetaType::QString, 0x00095001,
       7, QMetaType::Bool, 0x00095001,
       8, QMetaType::Bool, 0x00095001,
       9, QMetaType::Bool, 0x00095001,

 // enums: name, alias, flags, count, data
       5,   10, 0x1,   15,   43,

 // enum data: key, value
      11, uint(KContacts::PhoneNumber::Home),
      12, uint(KContacts::PhoneNumber::Work),
      13, uint(KContacts::PhoneNumber::Msg),
      14, uint(KContacts::PhoneNumber::Pref),
      15, uint(KContacts::PhoneNumber::Voice),
      16, uint(KContacts::PhoneNumber::Fax),
      17, uint(KContacts::PhoneNumber::Cell),
      18, uint(KContacts::PhoneNumber::Video),
      19, uint(KContacts::PhoneNumber::Bbs),
      20, uint(KContacts::PhoneNumber::Modem),
      21, uint(KContacts::PhoneNumber::Car),
      22, uint(KContacts::PhoneNumber::Isdn),
      23, uint(KContacts::PhoneNumber::Pcs),
      24, uint(KContacts::PhoneNumber::Pager),
      25, uint(KContacts::PhoneNumber::Undefined),

       0        // eod
};

void KContacts::PhoneNumber::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<PhoneNumber *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->number(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->normalizedNumber(); break;
        case 3: *reinterpret_cast<int*>(_v) = QFlag(_t->type()); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->typeLabel(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isEmpty(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->isPreferred(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->supportsSms(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<PhoneNumber *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setNumber(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setType(QFlag(*reinterpret_cast<int*>(_v))); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KContacts::PhoneNumber::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts__PhoneNumber.data,
    qt_meta_data_KContacts__PhoneNumber,
    qt_static_metacall,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
