/****************************************************************************
** Meta object code from reading C++ file 'impp.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kcontacts-5.116.0/src/impp.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'impp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KContacts__Impp_t {
    QByteArrayData data[7];
    char stringdata0[81];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts__Impp_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts__Impp_t qt_meta_stringdata_KContacts__Impp = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KContacts::Impp"
QT_MOC_LITERAL(1, 16, 7), // "isValid"
QT_MOC_LITERAL(2, 24, 7), // "address"
QT_MOC_LITERAL(3, 32, 11), // "isPreferred"
QT_MOC_LITERAL(4, 44, 11), // "serviceType"
QT_MOC_LITERAL(5, 56, 12), // "serviceLabel"
QT_MOC_LITERAL(6, 69, 11) // "serviceIcon"

    },
    "KContacts::Impp\0isValid\0address\0"
    "isPreferred\0serviceType\0serviceLabel\0"
    "serviceIcon"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts__Impp[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       6,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::Bool, 0x00095001,
       2, QMetaType::QUrl, 0x00095103,
       3, QMetaType::Bool, 0x00095003,
       4, QMetaType::QString, 0x00095001,
       5, QMetaType::QString, 0x00095001,
       6, QMetaType::QString, 0x00095001,

       0        // eod
};

void KContacts::Impp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<Impp *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isValid(); break;
        case 1: *reinterpret_cast< QUrl*>(_v) = _t->address(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isPreferred(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->serviceType(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->serviceLabel(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->serviceIcon(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<Impp *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setAddress(*reinterpret_cast< QUrl*>(_v)); break;
        case 2: _t->setPreferred(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KContacts::Impp::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts__Impp.data,
    qt_meta_data_KContacts__Impp,
    qt_static_metacall,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
