/****************************************************************************
** Meta object code from reading C++ file 'address.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kcontacts-5.116.0/src/address.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'address.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KContacts__Address_t {
    QByteArrayData data[32];
    char stringdata0[276];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts__Address_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts__Address_t qt_meta_stringdata_KContacts__Address = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KContacts::Address"
QT_MOC_LITERAL(1, 19, 9), // "formatted"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 29), // "KContacts::AddressFormatStyle"
QT_MOC_LITERAL(4, 60, 5), // "style"
QT_MOC_LITERAL(5, 66, 8), // "realName"
QT_MOC_LITERAL(6, 75, 8), // "orgaName"
QT_MOC_LITERAL(7, 84, 2), // "id"
QT_MOC_LITERAL(8, 87, 7), // "isEmpty"
QT_MOC_LITERAL(9, 95, 4), // "type"
QT_MOC_LITERAL(10, 100, 4), // "Type"
QT_MOC_LITERAL(11, 105, 9), // "typeLabel"
QT_MOC_LITERAL(12, 115, 13), // "postOfficeBox"
QT_MOC_LITERAL(13, 129, 8), // "extended"
QT_MOC_LITERAL(14, 138, 6), // "street"
QT_MOC_LITERAL(15, 145, 8), // "locality"
QT_MOC_LITERAL(16, 154, 6), // "region"
QT_MOC_LITERAL(17, 161, 10), // "postalCode"
QT_MOC_LITERAL(18, 172, 7), // "country"
QT_MOC_LITERAL(19, 180, 5), // "label"
QT_MOC_LITERAL(20, 186, 3), // "geo"
QT_MOC_LITERAL(21, 190, 14), // "KContacts::Geo"
QT_MOC_LITERAL(22, 205, 16), // "formattedAddress"
QT_MOC_LITERAL(23, 222, 6), // "geoUri"
QT_MOC_LITERAL(24, 229, 8), // "TypeFlag"
QT_MOC_LITERAL(25, 238, 3), // "Dom"
QT_MOC_LITERAL(26, 242, 4), // "Intl"
QT_MOC_LITERAL(27, 247, 6), // "Postal"
QT_MOC_LITERAL(28, 254, 6), // "Parcel"
QT_MOC_LITERAL(29, 261, 4), // "Home"
QT_MOC_LITERAL(30, 266, 4), // "Work"
QT_MOC_LITERAL(31, 271, 4) // "Pref"

    },
    "KContacts::Address\0formatted\0\0"
    "KContacts::AddressFormatStyle\0style\0"
    "realName\0orgaName\0id\0isEmpty\0type\0"
    "Type\0typeLabel\0postOfficeBox\0extended\0"
    "street\0locality\0region\0postalCode\0"
    "country\0label\0geo\0KContacts::Geo\0"
    "formattedAddress\0geoUri\0TypeFlag\0Dom\0"
    "Intl\0Postal\0Parcel\0Home\0Work\0Pref"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts__Address[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
      15,   44, // properties
       1,   89, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    3,   29,    2, 0x02 /* Public */,
       1,    2,   36,    2, 0x22 /* Public | MethodCloned */,
       1,    1,   41,    2, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    QMetaType::QString, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    4,    5,    6,
    QMetaType::QString, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::QString, 0x80000000 | 3,    4,

 // properties: name, type, flags
       7, QMetaType::QString, 0x00095103,
       8, QMetaType::Bool, 0x00095001,
       9, 0x80000000 | 10, 0x0009510b,
      11, QMetaType::QString, 0x00095001,
      12, QMetaType::QString, 0x00095103,
      13, QMetaType::QString, 0x00095103,
      14, QMetaType::QString, 0x00095103,
      15, QMetaType::QString, 0x00095103,
      16, QMetaType::QString, 0x00095103,
      17, QMetaType::QString, 0x00095103,
      18, QMetaType::QString, 0x00095103,
      19, QMetaType::QString, 0x00095103,
      20, 0x80000000 | 21, 0x0009510b,
      22, QMetaType::QString, 0x00095001,
      23, QMetaType::QUrl, 0x00095001,

 // enums: name, alias, flags, count, data
      10,   24, 0x1,    7,   94,

 // enum data: key, value
      25, uint(KContacts::Address::Dom),
      26, uint(KContacts::Address::Intl),
      27, uint(KContacts::Address::Postal),
      28, uint(KContacts::Address::Parcel),
      29, uint(KContacts::Address::Home),
      30, uint(KContacts::Address::Work),
      31, uint(KContacts::Address::Pref),

       0        // eod
};

void KContacts::Address::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = reinterpret_cast<Address *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QString _r = _t->formatted((*reinterpret_cast< KContacts::AddressFormatStyle(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->formatted((*reinterpret_cast< KContacts::AddressFormatStyle(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->formatted((*reinterpret_cast< KContacts::AddressFormatStyle(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KContacts::Geo >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<Address *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isEmpty(); break;
        case 2: *reinterpret_cast<int*>(_v) = QFlag(_t->type()); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->typeLabel(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->postOfficeBox(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->extended(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->street(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->locality(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->region(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->postalCode(); break;
        case 10: *reinterpret_cast< QString*>(_v) = _t->country(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->label(); break;
        case 12: *reinterpret_cast< KContacts::Geo*>(_v) = _t->geo(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->formattedPostalAddress(); break;
        case 14: *reinterpret_cast< QUrl*>(_v) = _t->geoUri(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<Address *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setType(QFlag(*reinterpret_cast<int*>(_v))); break;
        case 4: _t->setPostOfficeBox(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setExtended(*reinterpret_cast< QString*>(_v)); break;
        case 6: _t->setStreet(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setLocality(*reinterpret_cast< QString*>(_v)); break;
        case 8: _t->setRegion(*reinterpret_cast< QString*>(_v)); break;
        case 9: _t->setPostalCode(*reinterpret_cast< QString*>(_v)); break;
        case 10: _t->setCountry(*reinterpret_cast< QString*>(_v)); break;
        case 11: _t->setLabel(*reinterpret_cast< QString*>(_v)); break;
        case 12: _t->setGeo(*reinterpret_cast< KContacts::Geo*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_KContacts__Address[] = {
    QMetaObject::SuperData::link<KContacts::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject KContacts::Address::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts__Address.data,
    qt_meta_data_KContacts__Address,
    qt_static_metacall,
    qt_meta_extradata_KContacts__Address,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
