/****************************************************************************
** Meta object code from reading C++ file 'namespace.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kcontacts-5.116.0/src/namespace.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'namespace.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KContacts_t {
    QByteArrayData data[27];
    char stringdata0[373];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts_t qt_meta_stringdata_KContacts = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KContacts"
QT_MOC_LITERAL(1, 10, 18), // "AddressFormatStyle"
QT_MOC_LITERAL(2, 29, 6), // "Postal"
QT_MOC_LITERAL(3, 36, 17), // "MultiLineDomestic"
QT_MOC_LITERAL(4, 54, 22), // "MultiLineInternational"
QT_MOC_LITERAL(5, 77, 18), // "SingleLineDomestic"
QT_MOC_LITERAL(6, 96, 23), // "SingleLineInternational"
QT_MOC_LITERAL(7, 120, 11), // "GeoUriQuery"
QT_MOC_LITERAL(8, 132, 18), // "AddressFormatField"
QT_MOC_LITERAL(9, 151, 7), // "NoField"
QT_MOC_LITERAL(10, 159, 7), // "Country"
QT_MOC_LITERAL(11, 167, 6), // "Region"
QT_MOC_LITERAL(12, 174, 8), // "Locality"
QT_MOC_LITERAL(13, 183, 17), // "DependentLocality"
QT_MOC_LITERAL(14, 201, 11), // "SortingCode"
QT_MOC_LITERAL(15, 213, 10), // "PostalCode"
QT_MOC_LITERAL(16, 224, 13), // "StreetAddress"
QT_MOC_LITERAL(17, 238, 12), // "Organization"
QT_MOC_LITERAL(18, 251, 4), // "Name"
QT_MOC_LITERAL(19, 256, 13), // "PostOfficeBox"
QT_MOC_LITERAL(20, 270, 19), // "AddressFormatFields"
QT_MOC_LITERAL(21, 290, 29), // "AddressFormatScriptPreference"
QT_MOC_LITERAL(22, 320, 5), // "Local"
QT_MOC_LITERAL(23, 326, 5), // "Latin"
QT_MOC_LITERAL(24, 332, 23), // "AddressFormatPreference"
QT_MOC_LITERAL(25, 356, 7), // "Generic"
QT_MOC_LITERAL(26, 364, 8) // "Business"

    },
    "KContacts\0AddressFormatStyle\0Postal\0"
    "MultiLineDomestic\0MultiLineInternational\0"
    "SingleLineDomestic\0SingleLineInternational\0"
    "GeoUriQuery\0AddressFormatField\0NoField\0"
    "Country\0Region\0Locality\0DependentLocality\0"
    "SortingCode\0PostalCode\0StreetAddress\0"
    "Organization\0Name\0PostOfficeBox\0"
    "AddressFormatFields\0AddressFormatScriptPreference\0"
    "Local\0Latin\0AddressFormatPreference\0"
    "Generic\0Business"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       5,   14, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // enums: name, alias, flags, count, data
       1,    1, 0x2,    6,   39,
       8,    8, 0x2,   11,   51,
      20,    8, 0x3,   11,   73,
      21,   21, 0x2,    2,   95,
      24,   24, 0x2,    2,   99,

 // enum data: key, value
       2, uint(KContacts::AddressFormatStyle::Postal),
       3, uint(KContacts::AddressFormatStyle::MultiLineDomestic),
       4, uint(KContacts::AddressFormatStyle::MultiLineInternational),
       5, uint(KContacts::AddressFormatStyle::SingleLineDomestic),
       6, uint(KContacts::AddressFormatStyle::SingleLineInternational),
       7, uint(KContacts::AddressFormatStyle::GeoUriQuery),
       9, uint(KContacts::AddressFormatField::NoField),
      10, uint(KContacts::AddressFormatField::Country),
      11, uint(KContacts::AddressFormatField::Region),
      12, uint(KContacts::AddressFormatField::Locality),
      13, uint(KContacts::AddressFormatField::DependentLocality),
      14, uint(KContacts::AddressFormatField::SortingCode),
      15, uint(KContacts::AddressFormatField::PostalCode),
      16, uint(KContacts::AddressFormatField::StreetAddress),
      17, uint(KContacts::AddressFormatField::Organization),
      18, uint(KContacts::AddressFormatField::Name),
      19, uint(KContacts::AddressFormatField::PostOfficeBox),
       9, uint(KContacts::AddressFormatField::NoField),
      10, uint(KContacts::AddressFormatField::Country),
      11, uint(KContacts::AddressFormatField::Region),
      12, uint(KContacts::AddressFormatField::Locality),
      13, uint(KContacts::AddressFormatField::DependentLocality),
      14, uint(KContacts::AddressFormatField::SortingCode),
      15, uint(KContacts::AddressFormatField::PostalCode),
      16, uint(KContacts::AddressFormatField::StreetAddress),
      17, uint(KContacts::AddressFormatField::Organization),
      18, uint(KContacts::AddressFormatField::Name),
      19, uint(KContacts::AddressFormatField::PostOfficeBox),
      22, uint(KContacts::AddressFormatScriptPreference::Local),
      23, uint(KContacts::AddressFormatScriptPreference::Latin),
      25, uint(KContacts::AddressFormatPreference::Generic),
      26, uint(KContacts::AddressFormatPreference::Business),

       0        // eod
};

QT_INIT_METAOBJECT const QMetaObject KContacts::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts.data,
    qt_meta_data_KContacts,
    nullptr,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
