/****************************************************************************
** Meta object code from reading C++ file 'addressformat.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kcontacts-5.116.0/src/addressformat.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addressformat.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KContacts__AddressFormatElement_t {
    QByteArrayData data[7];
    char stringdata0[106];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts__AddressFormatElement_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts__AddressFormatElement_t qt_meta_stringdata_KContacts__AddressFormatElement = {
    {
QT_MOC_LITERAL(0, 0, 31), // "KContacts::AddressFormatElement"
QT_MOC_LITERAL(1, 32, 7), // "isField"
QT_MOC_LITERAL(2, 40, 5), // "field"
QT_MOC_LITERAL(3, 46, 29), // "KContacts::AddressFormatField"
QT_MOC_LITERAL(4, 76, 9), // "isLiteral"
QT_MOC_LITERAL(5, 86, 7), // "literal"
QT_MOC_LITERAL(6, 94, 11) // "isSeparator"

    },
    "KContacts::AddressFormatElement\0isField\0"
    "field\0KContacts::AddressFormatField\0"
    "isLiteral\0literal\0isSeparator"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts__AddressFormatElement[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       5,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::Bool, 0x00095001,
       2, 0x80000000 | 3, 0x00095009,
       4, QMetaType::Bool, 0x00095001,
       5, QMetaType::QString, 0x00095001,
       6, QMetaType::Bool, 0x00095001,

       0        // eod
};

void KContacts::AddressFormatElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<AddressFormatElement *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isField(); break;
        case 1: *reinterpret_cast< KContacts::AddressFormatField*>(_v) = _t->field(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isLiteral(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->literal(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isSeparator(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

static const QMetaObject::SuperData qt_meta_extradata_KContacts__AddressFormatElement[] = {
    QMetaObject::SuperData::link<KContacts::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject KContacts::AddressFormatElement::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts__AddressFormatElement.data,
    qt_meta_data_KContacts__AddressFormatElement,
    qt_static_metacall,
    qt_meta_extradata_KContacts__AddressFormatElement,
    nullptr
} };

struct qt_meta_stringdata_KContacts__AddressFormat_t {
    QByteArrayData data[9];
    char stringdata0[182];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts__AddressFormat_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts__AddressFormat_t qt_meta_stringdata_KContacts__AddressFormat = {
    {
QT_MOC_LITERAL(0, 0, 24), // "KContacts::AddressFormat"
QT_MOC_LITERAL(1, 25, 7), // "country"
QT_MOC_LITERAL(2, 33, 8), // "elements"
QT_MOC_LITERAL(3, 42, 38), // "QList<KContacts::AddressForma..."
QT_MOC_LITERAL(4, 81, 14), // "requiredFields"
QT_MOC_LITERAL(5, 96, 30), // "KContacts::AddressFormatFields"
QT_MOC_LITERAL(6, 127, 10), // "usedFields"
QT_MOC_LITERAL(7, 138, 15), // "upperCaseFields"
QT_MOC_LITERAL(8, 154, 27) // "postalCodeRegularExpression"

    },
    "KContacts::AddressFormat\0country\0"
    "elements\0QList<KContacts::AddressFormatElement>\0"
    "requiredFields\0KContacts::AddressFormatFields\0"
    "usedFields\0upperCaseFields\0"
    "postalCodeRegularExpression"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts__AddressFormat[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       6,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095001,
       2, 0x80000000 | 3, 0x00095009,
       4, 0x80000000 | 5, 0x00095009,
       6, 0x80000000 | 5, 0x00095009,
       7, 0x80000000 | 5, 0x00095009,
       8, QMetaType::QString, 0x00095001,

       0        // eod
};

void KContacts::AddressFormat::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<KContacts::AddressFormatElement> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<AddressFormat *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->country(); break;
        case 1: *reinterpret_cast< QList<KContacts::AddressFormatElement>*>(_v) = _t->elementsForQml(); break;
        case 2: *reinterpret_cast< KContacts::AddressFormatFields*>(_v) = _t->requiredFields(); break;
        case 3: *reinterpret_cast< KContacts::AddressFormatFields*>(_v) = _t->usedFields(); break;
        case 4: *reinterpret_cast< KContacts::AddressFormatFields*>(_v) = _t->upperCaseFields(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->postalCodeRegularExpression(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
}

static const QMetaObject::SuperData qt_meta_extradata_KContacts__AddressFormat[] = {
    QMetaObject::SuperData::link<KContacts::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject KContacts::AddressFormat::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts__AddressFormat.data,
    qt_meta_data_KContacts__AddressFormat,
    qt_static_metacall,
    qt_meta_extradata_KContacts__AddressFormat,
    nullptr
} };

struct qt_meta_stringdata_KContacts__AddressFormatRepository_t {
    QByteArrayData data[9];
    char stringdata0[188];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts__AddressFormatRepository_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts__AddressFormatRepository_t qt_meta_stringdata_KContacts__AddressFormatRepository = {
    {
QT_MOC_LITERAL(0, 0, 34), // "KContacts::AddressFormatRepos..."
QT_MOC_LITERAL(1, 35, 16), // "formatForCountry"
QT_MOC_LITERAL(2, 52, 24), // "KContacts::AddressFormat"
QT_MOC_LITERAL(3, 77, 0), // ""
QT_MOC_LITERAL(4, 78, 11), // "countryCode"
QT_MOC_LITERAL(5, 90, 40), // "KContacts::AddressFormatScrip..."
QT_MOC_LITERAL(6, 131, 10), // "scriptPref"
QT_MOC_LITERAL(7, 142, 34), // "KContacts::AddressFormatPrefe..."
QT_MOC_LITERAL(8, 177, 10) // "formatPref"

    },
    "KContacts::AddressFormatRepository\0"
    "formatForCountry\0KContacts::AddressFormat\0"
    "\0countryCode\0KContacts::AddressFormatScriptPreference\0"
    "scriptPref\0KContacts::AddressFormatPreference\0"
    "formatPref"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts__AddressFormatRepository[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    3,   24,    3, 0x02 /* Public */,
       1,    2,   31,    3, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    0x80000000 | 2, QMetaType::QString, 0x80000000 | 5, 0x80000000 | 7,    4,    6,    8,
    0x80000000 | 2, QMetaType::QString, 0x80000000 | 5,    4,    6,

       0        // eod
};

void KContacts::AddressFormatRepository::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = reinterpret_cast<AddressFormatRepository *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { KContacts::AddressFormat _r = _t->formatForCountry((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KContacts::AddressFormatScriptPreference(*)>(_a[2])),(*reinterpret_cast< KContacts::AddressFormatPreference(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< KContacts::AddressFormat*>(_a[0]) = std::move(_r); }  break;
        case 1: { KContacts::AddressFormat _r = _t->formatForCountry((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< KContacts::AddressFormatScriptPreference(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< KContacts::AddressFormat*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KContacts::AddressFormatRepository::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts__AddressFormatRepository.data,
    qt_meta_data_KContacts__AddressFormatRepository,
    qt_static_metacall,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
