/****************************************************************************
** Meta object code from reading C++ file 'addressee.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kcontacts-5.116.0/src/addressee.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addressee.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KContacts__Addressee_t {
    QByteArrayData data[46];
    char stringdata0[476];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KContacts__Addressee_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KContacts__Addressee_t qt_meta_stringdata_KContacts__Addressee = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KContacts::Addressee"
QT_MOC_LITERAL(1, 21, 7), // "isEmpty"
QT_MOC_LITERAL(2, 29, 3), // "uid"
QT_MOC_LITERAL(3, 33, 4), // "name"
QT_MOC_LITERAL(4, 38, 13), // "formattedName"
QT_MOC_LITERAL(5, 52, 10), // "familyName"
QT_MOC_LITERAL(6, 63, 9), // "givenName"
QT_MOC_LITERAL(7, 73, 14), // "additionalName"
QT_MOC_LITERAL(8, 88, 6), // "prefix"
QT_MOC_LITERAL(9, 95, 6), // "suffix"
QT_MOC_LITERAL(10, 102, 8), // "nickName"
QT_MOC_LITERAL(11, 111, 8), // "birthday"
QT_MOC_LITERAL(12, 120, 15), // "birthdayHasTime"
QT_MOC_LITERAL(13, 136, 6), // "mailer"
QT_MOC_LITERAL(14, 143, 3), // "geo"
QT_MOC_LITERAL(15, 147, 14), // "KContacts::Geo"
QT_MOC_LITERAL(16, 162, 5), // "title"
QT_MOC_LITERAL(17, 168, 4), // "role"
QT_MOC_LITERAL(18, 173, 12), // "organization"
QT_MOC_LITERAL(19, 186, 10), // "department"
QT_MOC_LITERAL(20, 197, 4), // "note"
QT_MOC_LITERAL(21, 202, 9), // "productId"
QT_MOC_LITERAL(22, 212, 8), // "revision"
QT_MOC_LITERAL(23, 221, 10), // "sortString"
QT_MOC_LITERAL(24, 232, 3), // "url"
QT_MOC_LITERAL(25, 236, 29), // "KContacts::ResourceLocatorUrl"
QT_MOC_LITERAL(26, 266, 8), // "realName"
QT_MOC_LITERAL(27, 275, 13), // "assembledName"
QT_MOC_LITERAL(28, 289, 14), // "preferredEmail"
QT_MOC_LITERAL(29, 304, 10), // "categories"
QT_MOC_LITERAL(30, 315, 7), // "customs"
QT_MOC_LITERAL(31, 323, 7), // "changed"
QT_MOC_LITERAL(32, 331, 11), // "anniversary"
QT_MOC_LITERAL(33, 343, 14), // "assistantsName"
QT_MOC_LITERAL(34, 358, 8), // "blogFeed"
QT_MOC_LITERAL(35, 367, 12), // "managersName"
QT_MOC_LITERAL(36, 380, 6), // "office"
QT_MOC_LITERAL(37, 387, 10), // "profession"
QT_MOC_LITERAL(38, 398, 11), // "spousesName"
QT_MOC_LITERAL(39, 410, 5), // "photo"
QT_MOC_LITERAL(40, 416, 18), // "KContacts::Picture"
QT_MOC_LITERAL(41, 435, 6), // "emails"
QT_MOC_LITERAL(42, 442, 12), // "phoneNumbers"
QT_MOC_LITERAL(43, 455, 9), // "addresses"
QT_MOC_LITERAL(44, 465, 4), // "urls"
QT_MOC_LITERAL(45, 470, 5) // "impps"

    },
    "KContacts::Addressee\0isEmpty\0uid\0name\0"
    "formattedName\0familyName\0givenName\0"
    "additionalName\0prefix\0suffix\0nickName\0"
    "birthday\0birthdayHasTime\0mailer\0geo\0"
    "KContacts::Geo\0title\0role\0organization\0"
    "department\0note\0productId\0revision\0"
    "sortString\0url\0KContacts::ResourceLocatorUrl\0"
    "realName\0assembledName\0preferredEmail\0"
    "categories\0customs\0changed\0anniversary\0"
    "assistantsName\0blogFeed\0managersName\0"
    "office\0profession\0spousesName\0photo\0"
    "KContacts::Picture\0emails\0phoneNumbers\0"
    "addresses\0urls\0impps"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KContacts__Addressee[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
      42,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::Bool, 0x00095001,
       2, QMetaType::QString, 0x00095103,
       3, QMetaType::QString, 0x00095103,
       4, QMetaType::QString, 0x00095103,
       5, QMetaType::QString, 0x00095103,
       6, QMetaType::QString, 0x00095103,
       7, QMetaType::QString, 0x00095103,
       8, QMetaType::QString, 0x00095103,
       9, QMetaType::QString, 0x00095103,
      10, QMetaType::QString, 0x00095001,
      11, QMetaType::QDateTime, 0x00095003,
      12, QMetaType::Bool, 0x00095001,
      13, QMetaType::QString, 0x00095103,
      14, 0x80000000 | 15, 0x0009510b,
      16, QMetaType::QString, 0x00095001,
      17, QMetaType::QString, 0x00095001,
      18, QMetaType::QString, 0x00095001,
      19, QMetaType::QString, 0x00095103,
      20, QMetaType::QString, 0x00095103,
      21, QMetaType::QString, 0x00095103,
      22, QMetaType::QDateTime, 0x00095001,
      23, QMetaType::QString, 0x00095103,
      24, 0x80000000 | 25, 0x0009510b,
      26, QMetaType::QString, 0x00095001,
      27, QMetaType::QString, 0x00095001,
      28, QMetaType::QString, 0x00095001,
      29, QMetaType::QStringList, 0x00095103,
      30, QMetaType::QStringList, 0x00095001,
      31, QMetaType::Bool, 0x00095103,
      32, QMetaType::QDate, 0x00095103,
      33, QMetaType::QString, 0x00095103,
      34, QMetaType::QUrl, 0x00095103,
      35, QMetaType::QString, 0x00095103,
      36, QMetaType::QString, 0x00095103,
      37, QMetaType::QString, 0x00095103,
      38, QMetaType::QString, 0x00095103,
      39, 0x80000000 | 40, 0x0009510b,
      41, QMetaType::QVariantList, 0x00095003,
      42, QMetaType::QVariantList, 0x00095003,
      43, QMetaType::QVariantList, 0x00095001,
      44, QMetaType::QVariantList, 0x00095001,
      45, QMetaType::QVariantList, 0x00095003,

       0        // eod
};

void KContacts::Addressee::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KContacts::Geo >(); break;
        case 22:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KContacts::ResourceLocatorUrl >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<Addressee *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isEmpty(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->uid(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->formattedName(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->familyName(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->givenName(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->additionalName(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->prefix(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->suffix(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->nickName(); break;
        case 10: *reinterpret_cast< QDateTime*>(_v) = _t->birthday(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->birthdayHasTime(); break;
        case 12: *reinterpret_cast< QString*>(_v) = _t->mailer(); break;
        case 13: *reinterpret_cast< KContacts::Geo*>(_v) = _t->geo(); break;
        case 14: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 15: *reinterpret_cast< QString*>(_v) = _t->role(); break;
        case 16: *reinterpret_cast< QString*>(_v) = _t->organization(); break;
        case 17: *reinterpret_cast< QString*>(_v) = _t->department(); break;
        case 18: *reinterpret_cast< QString*>(_v) = _t->note(); break;
        case 19: *reinterpret_cast< QString*>(_v) = _t->productId(); break;
        case 20: *reinterpret_cast< QDateTime*>(_v) = _t->revision(); break;
        case 21: *reinterpret_cast< QString*>(_v) = _t->sortString(); break;
        case 22: *reinterpret_cast< KContacts::ResourceLocatorUrl*>(_v) = _t->url(); break;
        case 23: *reinterpret_cast< QString*>(_v) = _t->realName(); break;
        case 24: *reinterpret_cast< QString*>(_v) = _t->assembledName(); break;
        case 25: *reinterpret_cast< QString*>(_v) = _t->preferredEmail(); break;
        case 26: *reinterpret_cast< QStringList*>(_v) = _t->categories(); break;
        case 27: *reinterpret_cast< QStringList*>(_v) = _t->customs(); break;
        case 28: *reinterpret_cast< bool*>(_v) = _t->changed(); break;
        case 29: *reinterpret_cast< QDate*>(_v) = _t->anniversary(); break;
        case 30: *reinterpret_cast< QString*>(_v) = _t->assistantsName(); break;
        case 31: *reinterpret_cast< QUrl*>(_v) = _t->blogFeed(); break;
        case 32: *reinterpret_cast< QString*>(_v) = _t->managersName(); break;
        case 33: *reinterpret_cast< QString*>(_v) = _t->office(); break;
        case 34: *reinterpret_cast< QString*>(_v) = _t->profession(); break;
        case 35: *reinterpret_cast< QString*>(_v) = _t->spousesName(); break;
        case 36: *reinterpret_cast< KContacts::Picture*>(_v) = _t->photo(); break;
        case 37: *reinterpret_cast< QVariantList*>(_v) = _t->emailsVariant(); break;
        case 38: *reinterpret_cast< QVariantList*>(_v) = _t->phoneNumbersVariant(); break;
        case 39: *reinterpret_cast< QVariantList*>(_v) = _t->addressesVariant(); break;
        case 40: *reinterpret_cast< QVariantList*>(_v) = _t->urlsVariant(); break;
        case 41: *reinterpret_cast< QVariantList*>(_v) = _t->imppsVariant(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = reinterpret_cast<Addressee *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setUid(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setFormattedName(*reinterpret_cast< QString*>(_v)); break;
        case 4: _t->setFamilyName(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setGivenName(*reinterpret_cast< QString*>(_v)); break;
        case 6: _t->setAdditionalName(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setPrefix(*reinterpret_cast< QString*>(_v)); break;
        case 8: _t->setSuffix(*reinterpret_cast< QString*>(_v)); break;
        case 10: _t->setBirthdayProperty(*reinterpret_cast< QDateTime*>(_v)); break;
        case 12: _t->setMailer(*reinterpret_cast< QString*>(_v)); break;
        case 13: _t->setGeo(*reinterpret_cast< KContacts::Geo*>(_v)); break;
        case 17: _t->setDepartment(*reinterpret_cast< QString*>(_v)); break;
        case 18: _t->setNote(*reinterpret_cast< QString*>(_v)); break;
        case 19: _t->setProductId(*reinterpret_cast< QString*>(_v)); break;
        case 21: _t->setSortString(*reinterpret_cast< QString*>(_v)); break;
        case 22: _t->setUrl(*reinterpret_cast< KContacts::ResourceLocatorUrl*>(_v)); break;
        case 26: _t->setCategories(*reinterpret_cast< QStringList*>(_v)); break;
        case 28: _t->setChanged(*reinterpret_cast< bool*>(_v)); break;
        case 29: _t->setAnniversary(*reinterpret_cast< QDate*>(_v)); break;
        case 30: _t->setAssistantsName(*reinterpret_cast< QString*>(_v)); break;
        case 31: _t->setBlogFeed(*reinterpret_cast< QUrl*>(_v)); break;
        case 32: _t->setManagersName(*reinterpret_cast< QString*>(_v)); break;
        case 33: _t->setOffice(*reinterpret_cast< QString*>(_v)); break;
        case 34: _t->setProfession(*reinterpret_cast< QString*>(_v)); break;
        case 35: _t->setSpousesName(*reinterpret_cast< QString*>(_v)); break;
        case 36: _t->setPhoto(*reinterpret_cast< KContacts::Picture*>(_v)); break;
        case 37: _t->setEmailsVariant(*reinterpret_cast< QVariantList*>(_v)); break;
        case 38: _t->setPhoneNumbersVariant(*reinterpret_cast< QVariantList*>(_v)); break;
        case 41: _t->setImppsVariant(*reinterpret_cast< QVariantList*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
}

static const QMetaObject::SuperData qt_meta_extradata_KContacts__Addressee[] = {
    QMetaObject::SuperData::link<KContacts::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject KContacts::Addressee::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KContacts__Addressee.data,
    qt_meta_data_KContacts__Addressee,
    qt_static_metacall,
    qt_meta_extradata_KContacts__Addressee,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
